@@ -4,16 +4,17 @@ use base 'Templ::Tag';
 use strict;
 use warnings;
 
+use Templ::Util qw(default);
 use Carp qw(croak);
 
 sub perl {
     my $self    = shift;
-    my $content = defined($_[0]) ? shift : '';
-    my $indent  = defined($_[0]) ? shift : '';
-    my $append  = defined($_[0]) ? shift : '';
+    my $content = shift;
+    my $indent  = shift;
+    my $append  = shift;
 
     my $expr = $self->filter . "( $content )";
-    if ( $indent ne '' ) {
+    if ( default($indent) ne '' ) {
         $expr = "indent( '$indent', $expr )";
     }
 
@@ -30,7 +31,7 @@ sub check {
 
 sub filter {
     my $self = shift;
-    return ($self->params)[0];
+    return default $self->{'filter'};
 }
 
 1;
